@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.2.7'; # VERSION
+our $VERSION = 'v0.2.8'; # VERSION
 
 use Moose;
 with qw(
@@ -31,47 +31,63 @@ sub submit {
 
 	my $r = $self->_build_request( $payload );
 
-
 	my $res;
-	if ( $r->{decision} eq 'ACCEPT' ) {
+	if ( $r->{decision} eq 'ACCEPT' or $r->{decision} eq 'REJECT' ) {
+		my @traits = qw(Business::CyberSource::Response::Role::Authorization);
 
-		my $cv = { };
+		my $e = { };
 
-		if ( $r->{cvCode} and $r->{cvCodeRaw} ) {
-			$cv->{cv_code}     = $r->{cvCode};
-			$cv->{cv_code_raw} = $r->{cvCodeRaw};
+		if ( $r->{decision} eq 'ACCEPT' ) {
+			push( @traits, 'Business::CyberSource::Response::Role::Accept' );
+			$e->{currency      } = $r->{purchaseTotals}{currency};
+			$e->{amount        } = $r->{ccAuthReply}->{amount};
+			$e->{datetime      } = $r->{ccAuthReply}{authorizedDateTime};
+			$e->{reference_code} = $r->{merchantReferenceCode};
+			$e->{request_specific_reason_code}
+				= "$r->{ccAuthReply}->{reasonCode}";
+		}
+
+		if ( $r->{ccAuthReply} ) {
+
+			$e->{auth_code}
+				=  $r->{ccAuthReply}{authorizationCode }
+				if $r->{ccAuthReply}{authorizationCode }
+				;
+
+
+			if ( $r->{ccAuthReply}{cvCode}
+					&& $r->{ccAuthReply}{cvCodeRaw}
+				) {
+				$e->{cv_code}     = $r->{ccAuthReply}{cvCode};
+				$e->{cv_code_raw} = $r->{ccAuthReply}{cvCodeRaw};
+			}
+
+			if ( $r->{ccAuthReply}{avsCode}
+					&& $r->{ccAuthReply}{avsCodeRaw}
+				) {
+				$e->{avs_code}     = $r->{ccAuthReply}{avsCode};
+				$e->{avs_code_raw} = $r->{ccAuthReply}{avsCodeRaw};
+			}
 		}
 
 		$res
 			= Business::CyberSource::Response
-			->with_traits(qw{
-				Business::CyberSource::Response::Role::Authorization
-				Business::CyberSource::Response::Role::Accept
-			})
+			->with_traits( @traits )
 			->new({
 				request_id     => $r->{requestID},
 				decision       => $r->{decision},
 				# quote reason_code to stringify from BigInt
 				reason_code    => "$r->{reasonCode}",
 				request_token  => $r->{requestToken},
-				reference_code => $r->{merchantReferenceCode},
-				currency       => $r->{purchaseTotals}->{currency},
-				amount         => $r->{ccAuthReply}->{amount},
-				avs_code_raw   => $r->{ccAuthReply}->{avsCodeRaw},
-				avs_code       => $r->{ccAuthReply}->{avsCode},
-				datetime       => $r->{ccAuthReply}->{authorizedDateTime},
 				auth_record    => $r->{ccAuthReply}->{authRecord},
-				auth_code      => $r->{ccAuthReply}->{authorizationCode},
 				processor_response =>
 					$r->{ccAuthReply}->{processorResponse},
-				request_specific_reason_code =>
-					"$r->{ccAuthReply}->{reasonCode}",
-				%{$cv},
+				%{$e},
 			})
 			;
 	}
 	else {
-		$res = $self->_handle_decision( $r );
+		croak 'decision defined, but not sane: ' . $r->{decision};
 	}
 
 	return $res;
@@ -92,7 +108,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version v0.2.7
+version v0.2.8
 
 =head1 SYNOPSIS
 
