@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.7'; # VERSION
+our $VERSION = 'v0.2.8'; # VERSION
 
 use Moose::Role;
 use MooseX::Types::Moose   qw( HashRef );
@@ -64,13 +64,15 @@ sub _handle_decision {
 	my ( $self, $r ) = @_;
 
 	my $res;
-	if ( $r->{decision} eq 'REJECT' or $r->{decision} eq 'ERROR' ) {
-		$res = Business::CyberSource::Response->new({
-			decision      => $r->{decision},
-			request_id    => $r->{requestID},
-			reason_code   => "$r->{reasonCode}",
-			request_token => $r->{requestToken},
-		});
+	if ( $r->{decision} eq 'REJECT' ) {
+		$res
+			= Business::CyberSource::Response
+			->new({
+				decision      => $r->{decision},
+				request_id    => $r->{requestID},
+				reason_code   => "$r->{reasonCode}",
+				request_token => $r->{requestToken},
+			});
 	}
 	else {
 		croak 'decision defined, but not sane: ' . $r->{decision};
@@ -103,7 +105,7 @@ Business::CyberSource::Request::Role::Common - Request Role
 
 =head1 VERSION
 
-version v0.2.7
+version v0.2.8
 
 =head1 BUGS
 
